<?php

namespace Hrm\Manpower\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hrm\Manpower\Models\Manpower;

class ManpowerPolicy
{

    /**
     * Determine if the given user can view the manpower.
     *
     * @param UserPolicy $user
     * @param Manpower $manpower
     *
     * @return bool
     */
    public function view(UserPolicy $user, Manpower $manpower)
    {
        if ($user->canDo('manpower.manpower.view') && $user->isAdmin()) {
            return true;
        }

        return $manpower->user_id == user_id() && $manpower->user_type == user_type();
    }

    /**
     * Determine if the given user can create a manpower.
     *
     * @param UserPolicy $user
     * @param Manpower $manpower
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('manpower.manpower.create');
    }

    /**
     * Determine if the given user can update the given manpower.
     *
     * @param UserPolicy $user
     * @param Manpower $manpower
     *
     * @return bool
     */
    public function update(UserPolicy $user, Manpower $manpower)
    {
        if ($user->canDo('manpower.manpower.edit') && $user->isAdmin()) {
            return true;
        }

        return $manpower->user_id == user_id() && $manpower->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given manpower.
     *
     * @param UserPolicy $user
     * @param Manpower $manpower
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Manpower $manpower)
    {
        return $manpower->user_id == user_id() && $manpower->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given manpower.
     *
     * @param UserPolicy $user
     * @param Manpower $manpower
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Manpower $manpower)
    {
        if ($user->canDo('manpower.manpower.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given manpower.
     *
     * @param UserPolicy $user
     * @param Manpower $manpower
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Manpower $manpower)
    {
        if ($user->canDo('manpower.manpower.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
